Publisher

Struct Publisher 

pub struct Publisher { /* private fields */ }
Publisher is a scheduler which is designed for Pub/Sub’s Publish flow. Each item is added with a given key. Items added to the empty string key are handled in random order. Items added to any other key are handled sequentially.

Implementations

Source

impl Publisher

pub async fn publish_immediately( &self, messages: Vec<PubsubMessage>, retry: Option<RetrySetting>, ) -> Result<Vec<String>, Status>

publish publishes msg to the topic synchronously

pub async fn publish(&self, message: PubsubMessage) -> Awaiter

publish publishes msg to the topic asynchronously. Messages are batched and sent according to the topic’s PublisherConfig. Publish never blocks.

publish returns a non-nil Awaiter which will be ready when the message has been sent (or has failed to be sent) to the server.

pub fn publish_blocking(&self, message: PubsubMessage) -> Awaiter

Publish a message to the topic asynchronously, from synchronous code. This method blocks until the message is sent to the publisher channel. The actual publishing to the server is done asynchronously.

pub async fn publish_bulk(&self, messages: Vec<PubsubMessage>) -> Vec<Awaiter>

publish_bulk publishes msg to the topic asynchronously. Messages are batched and sent according to the topic’s PublisherConfig. Publish never blocks.

publish_bulk returns a non-nil Awaiter which will be ready when the message has been sent (or has failed to be sent) to the server.

pub async fn shutdown(&mut self)