pub struct ReceivedMessage {
pub message: PubsubMessage,
pub ack_id: String,
pub subscription: String,
pub subscriber_client: SubscriberClient,
pub delivery_attempt: Option<usize>,
}Fields
message: PubsubMessageack_id: Stringsubscription: Stringsubscriber_client: SubscriberClientdelivery_attempt: Option<usize>Implementations
Sourceimpl ReceivedMessage
impl ReceivedMessage
pub fn ack_id(&self) -> &str
pub async fn ack(&self) -> Result<(), Status>
pub async fn nack(&self) -> Result<(), Status>
pub async fn modify_ack_deadline( &self, ack_deadline_seconds: i32, ) -> Result<(), Status>
Sourcepub fn delivery_attempt(&self) -> Option<usize>
pub fn delivery_attempt(&self) -> Option<usize>
The approximate number of times that Cloud Pub/Sub has attempted to deliver the associated message to a subscriber.
The returned value, if present, will be greater than zero.
For more information refer to the protobuf definition.